pub enum ConfigError {
HomeDirectoryNotSet,
NotFound {
path: PathBuf,
},
Read {
path: PathBuf,
source: Error,
},
ParseTomlAtPath {
path: PathBuf,
source: Error,
},
ParseToml {
source: Error,
},
Validation(ConfigValidationError),
CreateConfigDir {
path: PathBuf,
source: Error,
},
SerializeDefaultConfig {
source: Error,
},
WriteDefaultConfig {
path: PathBuf,
source: Error,
},
}Expand description
Configuration load errors and the validated runtime policy derived from TOML. Errors while resolving, reading, parsing, or bootstrapping configuration files.
Variants
HomeDirectoryNotSet
NotFound
Read
ParseTomlAtPath
ParseToml
Validation(ConfigValidationError)
CreateConfigDir
SerializeDefaultConfig
WriteDefaultConfig