pub struct ChannelInfo {
pub name: String,
pub description: String,
}Expand description
MCP response types and the privacy-preserving project label helper. One configured vent channel exposed to MCP clients.
Fields
name: Stringdescription: StringTrait Implementations
Sourceimpl Clone for ChannelInfo
impl Clone for ChannelInfo
Sourcefn clone(&self) -> ChannelInfo
fn clone(&self) -> ChannelInfo
Returns a duplicate of the value. Read more
1.0.0 (const: unstable) · Sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
Performs copy-assignment from
source. Read moreSourceimpl Debug for ChannelInfo
impl Debug for ChannelInfo
Sourceimpl<'de> Deserialize<'de> for ChannelInfo
impl<'de> Deserialize<'de> for ChannelInfo
Sourcefn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
fn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
Deserialize this value from the given Serde deserializer. Read more
impl Eq for ChannelInfo
Sourceimpl JsonSchema for ChannelInfo
impl JsonSchema for ChannelInfo
Sourcefn schema_id() -> Cow<'static, str>
fn schema_id() -> Cow<'static, str>
Returns a string that uniquely identifies the schema produced by this type. Read more
Sourcefn json_schema(generator: &mut SchemaGenerator) -> Schema
fn json_schema(generator: &mut SchemaGenerator) -> Schema
Generates a JSON Schema for this type. Read more
Sourcefn inline_schema() -> bool
fn inline_schema() -> bool
Whether JSON Schemas generated for this type should be included directly in parent schemas,
rather than being re-used where possible using the
$ref keyword. Read moreSourceimpl PartialEq for ChannelInfo
impl PartialEq for ChannelInfo
Sourcefn eq(&self, other: &ChannelInfo) -> bool
fn eq(&self, other: &ChannelInfo) -> bool
Tests for
self and other values to be equal, and is used by ==.Sourceimpl Serialize for ChannelInfo
impl Serialize for ChannelInfo
impl StructuralPartialEq for ChannelInfo