pub struct ListChannelsOutput {
pub default_channel: String,
pub channels: Vec<ChannelInfo>,
}Expand description
MCP response types and the privacy-preserving project label helper.
Channel catalog returned by the list_channels MCP tool.
Fields
default_channel: Stringchannels: Vec<ChannelInfo>Trait Implementations
Sourceimpl Clone for ListChannelsOutput
impl Clone for ListChannelsOutput
Sourcefn clone(&self) -> ListChannelsOutput
fn clone(&self) -> ListChannelsOutput
Returns a duplicate of the value. Read more
1.0.0 (const: unstable) · Sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
Performs copy-assignment from
source. Read moreSourceimpl Debug for ListChannelsOutput
impl Debug for ListChannelsOutput
Sourceimpl<'de> Deserialize<'de> for ListChannelsOutput
impl<'de> Deserialize<'de> for ListChannelsOutput
Sourcefn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
fn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
Deserialize this value from the given Serde deserializer. Read more
impl Eq for ListChannelsOutput
Sourceimpl JsonSchema for ListChannelsOutput
impl JsonSchema for ListChannelsOutput
Sourcefn schema_id() -> Cow<'static, str>
fn schema_id() -> Cow<'static, str>
Returns a string that uniquely identifies the schema produced by this type. Read more
Sourcefn json_schema(generator: &mut SchemaGenerator) -> Schema
fn json_schema(generator: &mut SchemaGenerator) -> Schema
Generates a JSON Schema for this type. Read more
Sourcefn inline_schema() -> bool
fn inline_schema() -> bool
Whether JSON Schemas generated for this type should be included directly in parent schemas,
rather than being re-used where possible using the
$ref keyword. Read moreSourceimpl PartialEq for ListChannelsOutput
impl PartialEq for ListChannelsOutput
Sourcefn eq(&self, other: &ListChannelsOutput) -> bool
fn eq(&self, other: &ListChannelsOutput) -> bool
Tests for
self and other values to be equal, and is used by ==.Sourceimpl Serialize for ListChannelsOutput
impl Serialize for ListChannelsOutput
impl StructuralPartialEq for ListChannelsOutput