pub struct RuntimeConfig { /* private fields */ }Expand description
Configuration load errors and the validated runtime policy derived from TOML. Normalized runtime policy derived from validated TOML configuration.
Implementations
Sourceimpl RuntimeConfig
impl RuntimeConfig
Sourcepub fn default_channel(&self) -> &str
pub fn default_channel(&self) -> &str
Returns the channel used when callers omit an explicit channel.
Sourcepub fn has_channel(&self, name: &str) -> bool
pub fn has_channel(&self, name: &str) -> bool
Reports whether a channel name is configured.
Sourcepub fn has_only_default_channel(&self) -> bool
pub fn has_only_default_channel(&self) -> bool
True when only the default channel exists and channel choice can be hidden.
Sourcepub fn channel_list(&self) -> ListChannelsOutput
pub fn channel_list(&self) -> ListChannelsOutput
Builds the channel catalog exposed by the list_channels MCP tool.