pub struct VentOutput {
pub ok: bool,
pub event_id: String,
pub channel: String,
pub error: Option<String>,
}Expand description
MCP response types and the privacy-preserving project label helper. MCP acknowledgement for an accepted or rejected vent request.
Fields
ok: boolevent_id: StringShort trace id for the accepted event, not a deduplication key.
channel: Stringerror: Option<String>Trait Implementations
Sourceimpl Clone for VentOutput
impl Clone for VentOutput
Sourcefn clone(&self) -> VentOutput
fn clone(&self) -> VentOutput
Returns a duplicate of the value. Read more
1.0.0 (const: unstable) · Sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
Performs copy-assignment from
source. Read moreSourceimpl Debug for VentOutput
impl Debug for VentOutput
Sourceimpl<'de> Deserialize<'de> for VentOutput
impl<'de> Deserialize<'de> for VentOutput
Sourcefn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
fn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
Deserialize this value from the given Serde deserializer. Read more
impl Eq for VentOutput
Sourceimpl JsonSchema for VentOutput
impl JsonSchema for VentOutput
Sourcefn schema_id() -> Cow<'static, str>
fn schema_id() -> Cow<'static, str>
Returns a string that uniquely identifies the schema produced by this type. Read more
Sourcefn json_schema(generator: &mut SchemaGenerator) -> Schema
fn json_schema(generator: &mut SchemaGenerator) -> Schema
Generates a JSON Schema for this type. Read more
Sourcefn inline_schema() -> bool
fn inline_schema() -> bool
Whether JSON Schemas generated for this type should be included directly in parent schemas,
rather than being re-used where possible using the
$ref keyword. Read moreSourceimpl PartialEq for VentOutput
impl PartialEq for VentOutput
Sourcefn eq(&self, other: &VentOutput) -> bool
fn eq(&self, other: &VentOutput) -> bool
Tests for
self and other values to be equal, and is used by ==.Sourceimpl Serialize for VentOutput
impl Serialize for VentOutput
impl StructuralPartialEq for VentOutput